@@ -8,7 +8,7 @@ plot.biwavelet <-
             legend.loc=NULL, 
             legend.horiz=FALSE,
             arrow.size=0.08, arrow.lwd=2, arrow.cutoff=0.9, arrow.col="black", 
-            xlim = NULL, ylim = NULL,
+            arrow.nlocs.x=round(length(x$period)/2), arrow.nlocs.y=round(NCOL(x$wave)/2), xlim = NULL, ylim = NULL,
             xaxt = "s", yaxt = "s", form='%Y', ...) {
     if (bw) {
       bw.colors <- colorRampPalette(c("black", "white"))
@@ -159,8 +159,8 @@ plot.biwavelet <-
       ## Remove phases where power is weak
       locs=which (zvals < quantile(zvals, arrow.cutoff))
       a[locs]=NA
-      x.ind=seq(max(floor(x$dt/2),1), length(x$t), length.out=40)
-      y.ind=seq(max(floor(1/2),1), length(x$period), length.out=50)
+      x.ind=seq(max(floor(x$dt/2),1), length(x$t), length=round(min(arrow.nlocs.x, NCOL(x$wave))))
+      y.ind=seq(max(floor(1/2),1), length(x$period), length=round(min(arrow.nlocs.y, length(x$period))))
       phase.plot(x$t[x.ind], log2(x$period[y.ind]), a[y.ind, x.ind], 
                  arrow.size=arrow.size, arrow.lwd=arrow.lwd, arrow.col=arrow.col)    
     }
