@@ -1,7 +1,7 @@
 wtc <-
   function (d1, d2, pad=TRUE, dj=1/12, s0=2*dt, J1=NULL, max.scale=NULL, 
             mother=c("morlet", "paul", "dog"), param=-1, lag1=NULL, 
-            sig.level=0.95, sig.test = 0, nrands=300) {
+            sig.level=0.95, sig.test = 0, nrands=300, quiet = FALSE) {
     
     mothers=c("morlet", "paul", "dog")
     mother=match.arg(tolower(mother), mothers)
@@ -73,7 +73,7 @@ wtc <-
     if (nrands > 0) {
        signif=wtc.sig(nrands = nrands, lag1 = c(d1.ar1, d2.ar1), dt = dt, n, pad = pad, 
                      dj = dj, J1 = J1, s0 = s0, max.scale = max.scale, mother = mother, 
-                      sig.level = sig.level)
+                      sig.level = sig.level, quiet = quiet)
     }
     else
       signif=NA
